<?php
/**
 * Bootstrap Canvas WP Functions and Definitions
 */
 
if ( ! function_exists( 'bootstrapcanvaswp_setup' ) ) :
/**
 * Theme Setup
 */
function bootstrapcanvaswp_setup() {
  // Content Width
  global $content_width;
  if ( ! isset( $content_width ) ) {
    $content_width = 600;
  }
  
  // Editor Style
  add_editor_style( 'css/custom-editor-style.css' );
  
  // Post Thumbnails
  add_theme_support( 'post-thumbnails' );
  
  // Automatic Feed Links
  add_theme_support( 'automatic-feed-links' );
  
  // Theme Translation
  load_theme_textdomain( 'bootstrapcanvaswp', get_template_directory() . '/languages' );

  // Navigation Menus
  register_nav_menus( array(
	'primary' => __( 'Primary Menu', 'bootstrapcanvaswp' ),
  ) );
  
  // Custom Header
  $args = array(
	'flex-width'         => true,
	'width'              => 980,
	'flex-height'        => true,
	'height'             => 200,
	'default-text-color' => '333',
  );
  add_theme_support( 'custom-header', $args );
  
  // Custom Background
  $args = array(
	'default-color' => 'fff',
  );
  add_theme_support( 'custom-background', $args );
}
endif;
add_action( 'after_setup_theme', 'bootstrapcanvaswp_setup' );

/**
 * Scripts and Styles
 */
function bootstrapcanvaswp_scripts() {
  // Main Stylesheet
  wp_enqueue_style( 'bootstrapcanvaswp-style', get_stylesheet_uri() );
  if ( is_rtl() ) {
  wp_enqueue_style( 'bootstrapcanvaswp-style-rtl', get_template_directory_uri() . '/css/style-rtl.css' );
  }

  // Blog Stylesheet
  wp_enqueue_style( 'bootstrapcanvaswp-blog', get_template_directory_uri() . '/css/blog.css' );

  // Bootstrap CSS
  wp_enqueue_style( 'bootstrap.css', get_template_directory_uri() . '/css/bootstrap.css', '3.2.0' );

  // Optional Theme
  wp_enqueue_style( 'bootstrap-theme.css', get_template_directory_uri() . '/css/bootstrap-theme.css', '3.2.0' );

  // Bootstrap JavaScript
  wp_enqueue_script( 'bootstrap.js', get_template_directory_uri() . '/js/bootstrap.js', array( 'jquery' ), '3.2.0', true );

  wp_enqueue_script( 'html5shiv.js', get_template_directory_uri() . '/js/html5shiv.js', array( 'jquery' ), '3.7.2' );

  wp_enqueue_script( 'respond.js', get_template_directory_uri() . '/js/respond.js', array( 'jquery' ), '1.4.2' );
  
  // Comment Reply Script
  wp_enqueue_script( "comment-reply" );
}
add_action( 'wp_enqueue_scripts', 'bootstrapcanvaswp_scripts' );

/**
 * Widget Areas
 */
function bootstrapcanvaswp_widgets_init() {
  register_sidebar( array(
	'name'          => 'Right Sidebar',
	'id'            => 'sidebar-1',
	'description'   => __( 'Main sidebar that appears on the right.', 'bootstrapcanvaswp' ), 
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget'  => '</div>',
	'before_title'  => '<h4 class="widget-title">',
	'after_title'   => '</h4>',
  ) );
  
  register_sidebar( array(
	'name'          => 'Footer - Left',
	'id'            => 'footer-1',
	'description'   => __( 'Footer area that appears on the left.', 'bootstrapcanvaswp' ), 
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget'  => '</div>',
	'before_title'  => '<h4 class="widget-title">',
	'after_title'   => '</h4>',
  ) );
  
  register_sidebar( array(
	'name'          => 'Footer - Center',
	'id'            => 'footer-2',
	'description'   => __( 'Footer area that appears in the center.', 'bootstrapcanvaswp' ), 
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget'  => '</div>',
	'before_title'  => '<h4 class="widget-title">',
	'after_title'   => '</h4>',
  ) );
  
  register_sidebar( array(
	'name'          => 'Footer - Right',
	'id'            => 'footer-3',
	'description'   => __( 'Footer area that appears on the right.', 'bootstrapcanvaswp' ), 
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget'  => '</div>',
	'before_title'  => '<h4 class="widget-title">',
	'after_title'   => '</h4>',
  ) );
}
add_action( 'widgets_init', 'bootstrapcanvaswp_widgets_init' );

/**
 * Active Class
 */
function bootstrapcanvaswp_nav_class($classes, $item){
  if( in_array('current-menu-item', $classes) ){
	$classes[] = 'active ';
  }
  return $classes;
}
add_filter( 'nav_menu_css_class' , 'bootstrapcanvaswp_nav_class' , 10 , 2 );

/**
 * Excerpt More . . .
 */
function bootstrapcanvaswp_new_excerpt_more( $more ) {
  return ' . . .';
}
add_filter( 'excerpt_more', 'bootstrapcanvaswp_new_excerpt_more' );

/**
 * Comment Callback
 */
function bootstrapcanvaswp_comment($comment, $args, $depth) {
  $GLOBALS['comment'] = $comment;
  extract($args, EXTR_SKIP);

  if ( 'div' == $args['style'] ) {
	$tag = 'div';
	$add_below = 'comment';
  } else {
	$tag = 'li';
	$add_below = 'div-comment';
  }
?>
  <<?php echo $tag ?> id="comment-<?php comment_ID() ?>">
  <?php if ( 'div' != $args['style'] ) : ?>
  <div <?php comment_class( 'comment-body' ) ?> id="div-comment-<?php comment_ID() ?>">
  <?php endif; ?>
  <div class="avatar">
  <?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
  </div>
  <div class="media-body">
  <div class="comment-author vcard">
  <?php printf( __( '<cite class="fn">%s</cite> <span class="says">сказал:</span>' ), get_comment_author_link() ); ?>
  </div>
  <?php if ( $comment->comment_approved == '0' ) : ?>
    <em class="comment-awaiting-moderation"><?php _e( 'Ваш комментарий ожидает модерации.', 'bootstrapcanvaswp' ); ?></em>
    <br />
  <?php endif; ?>

  <div class="comment-meta commentmetadata"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
    <?php
      printf( __( '%1$s - %2$s', 'bootstrapcanvaswp' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Править)', 'bootstrapcanvaswp' ), '  ', '' );
    ?>
  </div>

  <?php comment_text(); ?>

  <div class="reply">
  <?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
  </div>
  </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif; ?>
<?php
}

/**
 * Theme Customization
 */
function bootstrapcanvaswp_customize_register( $wp_customize ) {
  // Header Customizer
  $wp_customize->add_section( 'header_image' , array(
    'title'    => __( 'Header', 'bootstrapcanvaswp' ),
  ) );
  
  $wp_customize->add_setting( 'logo', array(
    'default'           => '',
    'sanitize_callback' => 'esc_url_raw',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Image_Control( 
      $wp_customize, 
      'logo', 
      array(
		'label'    => __( 'Logo', 'bootstrapcanvaswp' ),
		'section'  => 'header_image',
		'settings' => 'logo',
		'priority' => '1',
      ) 
	) 
  );
  
  $wp_customize->add_control( 
  new WP_Customize_Color_Control( 
  $wp_customize, 
  'header_textcolor', 
  array(
	'label'    => __( 'Header Text Color', 'bootstrapcanvaswp' ),
	'section'  => 'header_image',
	'settings' => 'header_textcolor',
	'priority' => '2',
  ) ) 
  );
  
  $wp_customize->add_setting( 'header_color' , array(
    'default'  => '#f9f9f9',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
  new WP_Customize_Color_Control( 
  $wp_customize, 
  'header_color', 
  array(
	'label'    => __( 'Background Color', 'bootstrapcanvaswp' ),
	'section'  => 'header_image',
	'settings' => 'header_color',
	'priority' => '3',
  ) ) 
  );
  
  // Footer Customizer
  $wp_customize->add_section( 'bootstrapcanvaswp_footer' , array(
    'title'    => __( 'Footer', 'bootstrapcanvaswp' ),
  ) );
  
  $wp_customize->add_setting( 'copyright_text', array(
    'default'  => '',
    'sanitize_callback' => 'sanitize_text_field'
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Control( 
      $wp_customize, 
      'copyright_text', 
      array(
		'label'    => __( 'Copyright', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_footer',
		'settings' => 'copyright_text',
		'type'     => 'text',
		'priority' => '1',
      ) 
	) 
  );
  
  $wp_customize->add_setting( 'footer_textcolor' , array(
    'default'  => '#999',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'footer_textcolor', 
	  array(
		'label'    => __( 'Footer Text Color', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_footer',
		'settings' => 'footer_textcolor',
		'priority' => '2',
	  ) 
	) 
  );
  
  $wp_customize->add_setting( 'footer_color' , array(
    'default'  => '#f9f9f9',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'footer_color', 
	  array(
		'label'    => __( 'Background Color', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_footer',
		'settings' => 'footer_color',
		'priority' => '3',
	  ) 
	) 
  );
  
  // Text Customizer
  $wp_customize->add_section( 'bootstrapcanvaswp_text' , array(
    'title'    => __( 'Text', 'bootstrapcanvaswp' ),
  ) );
  
  $wp_customize->add_setting( 'font_family' , array(
    'default'  => 'Georgia, serif',
    'sanitize_callback' => 'bootstrapcanvaswp_sanitize_font_selection',
  ) );
  
  $wp_customize->add_control(
    new WP_Customize_Control(
	  $wp_customize,
	  'font_family',
	  array(
		'label'    => __( 'Font Family', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_text',
		'settings' => 'font_family',
		'priority' => '1',
		'type'     => 'select',
		'choices'  => array(
		  'Arial, Helvetica, sans-serif'                         => 'Arial',
		  '"Arial Black", Gadget, sans-serif'                    => 'Arial Black',
		  '"Comic Sans MS", cursive, sans-serif'                 => 'Comic Sans MS',
		  '"Courier New", Courier, monospace'                    => 'Courier New',
		  'Georgia, serif'                                       => 'Georgia',
		  'Impact, Charcoal, sans-serif'                         => 'Impact',
		  '"Lucida Console", Monaco, monospace'                  => 'Lucida Console',
		  '"Lucida Sans Unicode", "Lucida Grande", sans-serif'   => 'Lucida Sans Unicode',
		  '"Palatino Linotype", "Book Antiqua", Palatino, serif' => 'Palatino Linotype',
		  'Tahoma, Geneva, sans-serif'                           => 'Tahoma',
		  '"Times New Roman", Times, serif'                      => 'Times New Roman',
		  '"Trebuchet MS", Helvetica, sans-serif'                => 'Trebuchet MS',
		  'Verdana, Geneva, sans-serif'                          => 'Verdana',
	  )
    )
  ) );
  
  $wp_customize->add_setting( 'text_color' , array(
    'default'  => '#555',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'text_color', 
	  array(
		'label'    => __( 'Text color', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_text',
		'settings' => 'text_color',
		'priority' => '2',
	  )
	) 
  );
  
  $wp_customize->add_setting( 'headings_color' , array(
    'default'  => '#333',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
  	new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'headings_color', 
	  array(
		'label'    => __( 'Headings', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_text',
		'settings' => 'headings_color',
		'priority' => '3',
	  ) 
	) 
  );
  
  $wp_customize->add_setting( 'tracks_color' , array(
    'default'  => '#999',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'tracks_color', 
	  array(
		'label'    => __( 'Tracks (subtitles, captions, descriptions, chapters, or metadata)', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_text',
		'settings' => 'tracks_color',
		'priority' => '4',
	  )
	) 
  );
  
  $wp_customize->add_setting( 'link_color' , array(
    'default'  => '#428bca',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'link_color', 
	  array(
		'label'    => __( 'Links', 'bootstrapcanvaswp' ),
		'section'  => 'bootstrapcanvaswp_text',
		'settings' => 'link_color',
		'priority' => '5',
	  )
	) 
  );
  
  // Navigation Customizer
  $wp_customize->add_setting( 'nav_menu_color' , array(
    'default'  => '#428bca',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'nav_menu_color', 
	  array(
		'label'    => __( 'Navigation Menu', 'bootstrapcanvaswp' ),
		'section'  => 'nav',
		'settings' => 'nav_menu_color',
	  )	  
	) 
  );
  
  $wp_customize->add_setting( 'menu_item_color' , array(
    'default'  => '#cdddeb',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'menu_item_color', 
	  array(
		'label'    => __( 'Navigation Menu Item', 'bootstrapcanvaswp' ),
		'section'  => 'nav',
		'settings' => 'menu_item_color',
	  ) 
	) 
  );
  
  $wp_customize->add_setting( 'current_menu_item_color' , array(
    'default'  => '#fff',
    'sanitize_callback' => 'sanitize_hex_color',
  ) );
  
  $wp_customize->add_control( 
    new WP_Customize_Color_Control( 
	  $wp_customize, 
	  'current_menu_item_color', 
	  array(
		'label'    => __( 'Current Color', 'bootstrapcanvaswp' ),
		'section'  => 'nav',
		'settings' => 'current_menu_item_color',
	  )
	) 
  );
}
add_action( 'customize_register', 'bootstrapcanvaswp_customize_register' );

/**
 * Customization CSS
 */
function bootstrapcanvaswp_customize_css()
{
  ?>
    <style type="text/css">
	  body { color: <?php echo esc_html( get_theme_mod( 'text_color' )); ?>; font-family: <?php echo esc_html( get_theme_mod( 'font_family' )); ?> !important; }
	  h1, .h1, h2, .h2, h3, .h3, h4, .h4, h5, .h5, h6, .h6 { color: <?php echo esc_html( get_theme_mod( 'headings_color' )); ?>; }
	  a { color: <?php echo esc_html( get_theme_mod( 'link_color' )); ?>; }
	  img.attachment-thumbnail:hover, img.attachment-thumbnail:focus, img.attachment-thumbnail.active { border-color: <?php echo esc_html( get_theme_mod( 'link_color' )); ?> !important; }
	  .blog-masthead { background-color: <?php echo esc_html( get_theme_mod( 'nav_menu_color' )); ?>; }
	  .menu-item a { color: <?php echo esc_html( get_theme_mod( 'menu_item_color' )); ?>; }
	  .menu-item a:hover, .menu-item a:focus, .blog-nav-item:hover, .blog-nav-item:focus, .blog-nav .active a { color: <?php echo esc_html( get_theme_mod( 'current_menu_item_color' )); ?>; }
	  .blog-header { background-color: <?php echo esc_html( get_theme_mod( 'header_color' )); ?>; }
	  .blog-post-meta, .wp-caption-text, .gallery-caption, h1 small, h2 small, h3 small, h4 small, h5 small, h6 small, .h1 small, .h2 small, .h3 small, .h4 small, .h5 small, .h6 small, h1 .small, h2 .small, h3 .small, h4 .small, h5 .small, h6 .small, .h1 .small, .h2 .small, .h3 .small, .h4 .small, .h5 .small, .h6 .small { color: <?php echo esc_html( get_theme_mod( 'tracks_color' )); ?>; }
	  .blog-footer { background-color: <?php echo esc_html( get_theme_mod( 'footer_color' )); ?>; color: <?php echo esc_html( get_theme_mod( 'footer_textcolor' )); ?>; }
	</style>
  <?php
}
add_action( 'wp_head', 'bootstrapcanvaswp_customize_css');

/**
 * Data Sanitization
 */
function bootstrapcanvaswp_sanitize_font_selection( $input ) {
  $valid = array(
	  'Arial, Helvetica, sans-serif'                         => 'Arial',
	  '"Arial Black", Gadget, sans-serif'                    => 'Arial Black',
	  '"Comic Sans MS", cursive, sans-serif'                 => 'Comic Sans MS',
	  '"Courier New", Courier, monospace'                    => 'Courier New',
	  'Georgia, serif'                                       => 'Georgia',
	  'Impact, Charcoal, sans-serif'                         => 'Impact',
	  '"Lucida Console", Monaco, monospace'                  => 'Lucida Console',
	  '"Lucida Sans Unicode", "Lucida Grande", sans-serif'   => 'Lucida Sans Unicode',
	  '"Palatino Linotype", "Book Antiqua", Palatino, serif' => 'Palatino Linotype',
	  'Tahoma, Geneva, sans-serif'                           => 'Tahoma',
	  '"Times New Roman", Times, serif'                      => 'Times New Roman',
	  '"Trebuchet MS", Helvetica, sans-serif'                => 'Trebuchet MS',
	  'Verdana, Geneva, sans-serif'                          => 'Verdana',
  );
  if ( array_key_exists( $input, $valid ) ) {
	return $input;
  } else {
	return '';
  }
}